# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['NetappVolumeAttachmentArgs', 'NetappVolumeAttachment']

@pulumi.input_type
class NetappVolumeAttachmentArgs:
    def __init__(__self__, *,
                 netapp_volume_id: pulumi.Input[str],
                 vmware_cluster_id: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NetappVolumeAttachment resource.
        :param pulumi.Input[str] netapp_volume_id: The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] vmware_cluster_id: The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
               
               > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        :param pulumi.Input[str] name: The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        pulumi.set(__self__, "netapp_volume_id", netapp_volume_id)
        pulumi.set(__self__, "vmware_cluster_id", vmware_cluster_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="netappVolumeId")
    def netapp_volume_id(self) -> pulumi.Input[str]:
        """
        The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "netapp_volume_id")

    @netapp_volume_id.setter
    def netapp_volume_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "netapp_volume_id", value)

    @property
    @pulumi.getter(name="vmwareClusterId")
    def vmware_cluster_id(self) -> pulumi.Input[str]:
        """
        The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.

        > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        return pulumi.get(self, "vmware_cluster_id")

    @vmware_cluster_id.setter
    def vmware_cluster_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vmware_cluster_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _NetappVolumeAttachmentState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 netapp_volume_id: Optional[pulumi.Input[str]] = None,
                 vmware_cluster_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NetappVolumeAttachment resources.
        :param pulumi.Input[str] name: The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] netapp_volume_id: The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] vmware_cluster_id: The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
               
               > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if netapp_volume_id is not None:
            pulumi.set(__self__, "netapp_volume_id", netapp_volume_id)
        if vmware_cluster_id is not None:
            pulumi.set(__self__, "vmware_cluster_id", vmware_cluster_id)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="netappVolumeId")
    def netapp_volume_id(self) -> Optional[pulumi.Input[str]]:
        """
        The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "netapp_volume_id")

    @netapp_volume_id.setter
    def netapp_volume_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "netapp_volume_id", value)

    @property
    @pulumi.getter(name="vmwareClusterId")
    def vmware_cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.

        > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        return pulumi.get(self, "vmware_cluster_id")

    @vmware_cluster_id.setter
    def vmware_cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vmware_cluster_id", value)


class NetappVolumeAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 netapp_volume_id: Optional[pulumi.Input[str]] = None,
                 vmware_cluster_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a VMware Private Cloud Netapp File Attachment.

        ## Import

        VMware Private Clouds Netapp File Volume Attachment can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:avs/netappVolumeAttachment:NetappVolumeAttachment example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.AVS/privateClouds/privateCloud1/clusters/Cluster1/dataStores/datastore1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] netapp_volume_id: The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] vmware_cluster_id: The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
               
               > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetappVolumeAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a VMware Private Cloud Netapp File Attachment.

        ## Import

        VMware Private Clouds Netapp File Volume Attachment can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:avs/netappVolumeAttachment:NetappVolumeAttachment example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.AVS/privateClouds/privateCloud1/clusters/Cluster1/dataStores/datastore1
        ```

        :param str resource_name: The name of the resource.
        :param NetappVolumeAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetappVolumeAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 netapp_volume_id: Optional[pulumi.Input[str]] = None,
                 vmware_cluster_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetappVolumeAttachmentArgs.__new__(NetappVolumeAttachmentArgs)

            __props__.__dict__["name"] = name
            if netapp_volume_id is None and not opts.urn:
                raise TypeError("Missing required property 'netapp_volume_id'")
            __props__.__dict__["netapp_volume_id"] = netapp_volume_id
            if vmware_cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'vmware_cluster_id'")
            __props__.__dict__["vmware_cluster_id"] = vmware_cluster_id
        super(NetappVolumeAttachment, __self__).__init__(
            'azure:avs/netappVolumeAttachment:NetappVolumeAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            netapp_volume_id: Optional[pulumi.Input[str]] = None,
            vmware_cluster_id: Optional[pulumi.Input[str]] = None) -> 'NetappVolumeAttachment':
        """
        Get an existing NetappVolumeAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] netapp_volume_id: The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        :param pulumi.Input[str] vmware_cluster_id: The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
               
               > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetappVolumeAttachmentState.__new__(_NetappVolumeAttachmentState)

        __props__.__dict__["name"] = name
        __props__.__dict__["netapp_volume_id"] = netapp_volume_id
        __props__.__dict__["vmware_cluster_id"] = vmware_cluster_id
        return NetappVolumeAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this VMware Private Cloud Netapp File Volume Attachment. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="netappVolumeId")
    def netapp_volume_id(self) -> pulumi.Output[str]:
        """
        The netapp file volume for this VMware Private Cloud Netapp File Volume Attachment to connect to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.
        """
        return pulumi.get(self, "netapp_volume_id")

    @property
    @pulumi.getter(name="vmwareClusterId")
    def vmware_cluster_id(self) -> pulumi.Output[str]:
        """
        The vmware cluster for this VMware Private Cloud Netapp File Volume Attachment to associated to. Changing this forces a new VMware Private Cloud Netapp File Volume Attachment to be created.

        > **NOTE :** please follow the prerequisites mentioned in this [article](https://learn.microsoft.com/en-us/azure/azure-vmware/attach-azure-netapp-files-to-azure-vmware-solution-hosts?tabs=azure-portal#prerequisites) before associating the netapp file volume to the vmware solution hosts.
        """
        return pulumi.get(self, "vmware_cluster_id")

